@@ -769,7 +769,7 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
 
         users = ([{"email": "user2@email.com", "role": "viewer"}],)
         groups = ([{"group": "group4", "role": "viewer"}],)
-        everyone = "true"
+        everyone = "viewer"
 
         example_data_asset_id = "648473aa-791e-4372-bd25-205cc587ec56"
         input_json_data = {
